@@ -39,6 +39,10 @@
  *
  */
 
+/**
+ * @file
+ */
+
 #include <errno.h>
 
 #include "common/avl.h"
@@ -64,15 +68,29 @@
 #include "olsrv2/olsrv2_writer.h"
 
 /* definitions */
+
+/*! configuration option for locally attached networks */
 #define _LOCAL_ATTACHED_NETWORK_KEY "lan"
 
-#define LAN_DEFAULT_DOMAIN   0
-#define LAN_DEFAULT_METRIC   1
-#define LAN_DEFAULT_DISTANCE 2
+/**
+ * Default values for locally attached network parameters
+ */
+enum _lan_option_defaults {
+  LAN_DEFAULT_DOMAIN    = 0,//!< LAN_DEFAULT_DOMAIN
+  LAN_DEFAULT_METRIC    = 1,//!< LAN_DEFAULT_METRIC
+  LAN_DEFAULT_DISTANCE  = 2,//!< LAN_DEFAULT_DISTANCE
+};
 
+/*! locally attached network option for source-specific prefix */
 #define LAN_OPTION_SRC    "src="
+
+/*! locally attached network option for outgoing metric */
 #define LAN_OPTION_METRIC "metric="
+
+/*! locally attached network option for domain */
 #define LAN_OPTION_DOMAIN "domain="
+
+/*! locally attached network option for hopcount distance */
 #define LAN_OPTION_DIST   "dist="
 
 /**
@@ -124,7 +142,7 @@ static void _cleanup(void);
 static const char *_parse_lan_parameters(struct os_route_key *prefix,
 		struct _lan_data *dst, const char *src);
 static void _parse_lan_array(struct cfg_named_section *section, bool add);
-static void _cb_generate_tc(void *);
+static void _cb_generate_tc(struct oonf_timer_instance *);
 
 static void _update_originator(int af_family);
 static int _cb_if_event(struct oonf_interface_listener *);
@@ -173,7 +191,7 @@ static struct cfg_schema_entry _olsrv2_entries[] = {
     " ip address or prefix followed by an up to four optional parameters"
     " which define link metric cost, hopcount distance and domain of the prefix"
     " ( <"LAN_OPTION_METRIC"...> <"LAN_OPTION_DIST"...>"
-    " <"LAN_OPTION_DOMAIN"...> <"LAN_OPTION_SRC"...> ).",
+    " <"LAN_OPTION_DOMAIN"<num>/all> <"LAN_OPTION_SRC"...> ).",
     .list = true),
 
   CFG_MAP_ACL_V46(_config, originator_acl, "originator",
@@ -224,7 +242,7 @@ static struct oonf_timer_instance _tc_timer = {
 };
 
 /* global interface listener */
-struct oonf_interface_listener _if_listener = {
+static struct oonf_interface_listener _if_listener = {
   .process = _cb_if_event,
 };
 
@@ -260,13 +278,8 @@ _init(void) {
     return -1;
   }
 
-  _protocol = oonf_rfc5444_add_protocol(RFC5444_PROTOCOL, true);
-  if (_protocol == NULL) {
-    return -1;
-  }
-
+  _protocol = oonf_rfc5444_get_default_protocol();
   if (olsrv2_writer_init(_protocol)) {
-    oonf_rfc5444_remove_protocol(_protocol);
     return -1;
   }
 
@@ -315,7 +328,7 @@ _cleanup(void) {
   olsrv2_lan_cleanup();
 
   /* free protocol instance */
-  oonf_rfc5444_remove_protocol(_protocol);
+  _protocol = NULL;
 }
 
 /**
@@ -544,8 +557,8 @@ olsrv2_validate_lan(const struct cfg_schema_entry *entry,
         "    - '"LAN_OPTION_METRIC"<m>' the link metric of the LAN (between %u and %u)."
         " The default is 0.", RFC7181_METRIC_MIN, RFC7181_METRIC_MAX);
     cfg_append_printable_line(out,
-        "    - '"LAN_OPTION_DOMAIN"<d>' the domain of the LAN (between 0 and 255)."
-        " The default is 0.");
+        "    - '"LAN_OPTION_DOMAIN"<d>' the domain of the LAN (between 0 and 255) or 'all'."
+        " The default is all.");
     cfg_append_printable_line(out,
         "    - '"LAN_OPTION_DIST"<d>' the hopcount distance of the LAN (between 0 and 255)."
         " The default is 2.");
@@ -600,7 +613,7 @@ _parse_lan_parameters(struct os_route_key *prefix,
   unsigned ext;
 
   ptr = src;
-  dst->domain = nhdp_domain_get_by_ext(LAN_DEFAULT_DOMAIN);
+  dst->domain = NULL;
   dst->metric = LAN_DEFAULT_METRIC;
   dst->dist   = LAN_DEFAULT_DISTANCE;
 
@@ -614,13 +627,19 @@ _parse_lan_parameters(struct os_route_key *prefix,
       }
     }
     else if (strncasecmp(buffer, LAN_OPTION_DOMAIN, 7) == 0) {
-      ext = strtoul(&buffer[7], NULL, 10);
-      if ((ext == 0 && errno != 0) || ext > 255) {
-        return "an illegal domain parameter";
+      fprintf(stderr, "domain='%s'\n", &buffer[7]);
+      if (strcasecmp(&buffer[7], "all") == 0) {
+        dst->domain = NULL;
       }
-      dst->domain = nhdp_domain_get_by_ext(ext);
-      if (dst->domain == NULL) {
-        return "an unknown domain extension number";
+      else {
+        ext = strtoul(&buffer[7], NULL, 10);
+        if ((ext == 0 && errno != 0) || ext > 255) {
+          return "an illegal domain parameter";
+        }
+        dst->domain = nhdp_domain_get_by_ext(ext);
+        if (dst->domain == NULL) {
+          return "an unknown domain extension number";
+        }
       }
     }
     else if (strncasecmp(buffer, LAN_OPTION_DIST, 5) == 0) {
@@ -683,7 +702,7 @@ _parse_lan_array(struct cfg_named_section *section, bool add) {
       continue;
     }
 
-    os_route_init_sourcespec_prefix(&prefix, &addr);
+    os_routing_init_sourcespec_prefix(&prefix, &addr);
 
     /* truncate address */
     netaddr_truncate(&prefix.dst, &prefix.dst);
@@ -692,21 +711,33 @@ _parse_lan_array(struct cfg_named_section *section, bool add) {
       continue;
     }
 
-    if (add) {
-      olsrv2_lan_add(data.domain, &prefix, data.metric, data.dist);
+    if (data.domain == NULL) {
+      list_for_each_element(nhdp_domain_get_list(), data.domain, _node) {
+        if (add) {
+          olsrv2_lan_add(data.domain, &prefix, data.metric, data.dist);
+        }
+        else {
+          olsrv2_lan_remove(data.domain, &prefix);
+        }
+      }
     }
     else {
-      olsrv2_lan_remove(data.domain, &prefix);
+      if (add) {
+        olsrv2_lan_add(data.domain, &prefix, data.metric, data.dist);
+      }
+      else {
+        olsrv2_lan_remove(data.domain, &prefix);
+      }
     }
   }
 }
 
 /**
  * Callback to trigger normal tc generation with timer
- * @param ptr
+ * @param ptr timer instance that fired
  */
 static void
-_cb_generate_tc(void *ptr __attribute__((unused))) {
+_cb_generate_tc(struct oonf_timer_instance *ptr __attribute__((unused))) {
   if (nhdp_domain_node_is_mpr() || !avl_is_empty(olsrv2_lan_get_tree())) {
     olsrv2_writer_send_tc();
   }
